R/quantile_normalise_abundance.R
quantile_normalise_abundance-methods.Rdquantile_normalise_abundance() takes as input A `tbl` (with at least three columns for sample, feature and transcript abundance) or `SummarizedExperiment` (more convenient if abstracted to tibble with library(tidySummarizedExperiment)) and Scales transcript abundance compansating for sequencing depth (e.g., with TMM algorithm, Robinson and Oshlack doi.org/10.1186/gb-2010-11-3-r25).
quantile_normalise_abundance(
.data,
.abundance = NULL,
method = "limma_normalize_quantiles",
target_distribution = NULL
)
# S4 method for class 'SummarizedExperiment'
quantile_normalise_abundance(
.data,
.abundance = NULL,
method = "limma_normalize_quantiles",
target_distribution = NULL
)
# S4 method for class 'RangedSummarizedExperiment'
quantile_normalise_abundance(
.data,
.abundance = NULL,
method = "limma_normalize_quantiles",
target_distribution = NULL
)A `tbl` (with at least three columns for sample, feature and transcript abundance) or `SummarizedExperiment` (more convenient if abstracted to tibble with library(tidySummarizedExperiment))
The name of the transcript/gene abundance column
A character string. Either "limma_normalize_quantiles" for limma::normalizeQuantiles or "preprocesscore_normalize_quantiles_use_target" for preprocessCore::normalize.quantiles.use.target for large-scale datasets.
A numeric vector. If NULL the target distribution will be calculated by preprocessCore. This argument only affects the "preprocesscore_normalize_quantiles_use_target" method.
A tbl object with additional columns with scaled data as `<NAME OF COUNT COLUMN>_scaled`
A `SummarizedExperiment` object
A `SummarizedExperiment` object
`r lifecycle::badge("maturing")`
Tranform the feature abundance across samples so to have the same quantile distribution (using preprocessCore).
Underlying method
If `limma_normalize_quantiles` is chosen
.data |>limma::normalizeQuantiles()
If `preprocesscore_normalize_quantiles_use_target` is chosen
.data |> preprocessCore::normalize.quantiles.use.target( target = preprocessCore::normalize.quantiles.determine.target(.data) )
Mangiola, S., Molania, R., Dong, R., Doyle, M. A., & Papenfuss, A. T. (2021). tidybulk: an R tidy framework for modular transcriptomic data analysis. Genome Biology, 22(1), 42. doi:10.1186/s13059-020-02233-7
Ritchie, M. E., Phipson, B., Wu, D., Hu, Y., Law, C. W., Shi, W., & Smyth, G. K. (2015). limma powers differential expression analyses for RNA-sequencing and microarray studies. Nucleic Acids Research, 43(7), e47. doi:10.1093/nar/gkv007
## Load airway dataset for examples
data('airway', package = 'airway')
# Ensure a 'condition' column exists for examples expecting it
SummarizedExperiment::colData(airway)$condition <- SummarizedExperiment::colData(airway)$dex
airway |>
quantile_normalise_abundance()
#> # A SummarizedExperiment-tibble abstraction: Features=63677 | Samples=8 |
#> # Assays=counts, counts_scaled
#> # |--------- COVARIATES -------|
#> .feature .sample | counts counts_scaled | SampleName cell dex albut
#> <chr> <chr> | <chr> <chr> | <fct> <fct> <fct> <fct>
#> 1 ENSG000000… SRR103… | 679 691.25 | GSM1275862 N613… untrt untrt
#> 2 ENSG000000… SRR103… | 0 0 | GSM1275862 N613… untrt untrt
#> 3 ENSG000000… SRR103… | 467 469.375 | GSM1275862 N613… untrt untrt
#> 4 ENSG000000… SRR103… | 260 257.75 | GSM1275862 N613… untrt untrt
#> 5 ENSG000000… SRR103… | 60 58.625 | GSM1275862 N613… untrt untrt
#> -------- ------- - ------ ------------- - ---------- ---- --- -----
#> 509412 ENSG000002… SRR103… | 0 0 | GSM1275875 N061… trt untrt
#> 509413 ENSG000002… SRR103… | 0 0 | GSM1275875 N061… trt untrt
#> 509414 ENSG000002… SRR103… | 0 0 | GSM1275875 N061… trt untrt
#> 509415 ENSG000002… SRR103… | 0 0 | GSM1275875 N061… trt untrt
#> 509416 ENSG000002… SRR103… | 0 0 | GSM1275875 N061… trt untrt
#> # ℹ 17 more variables: Run <fct>, avgLength <chr>, Experiment <fct>,
#> # Sample <fct>, BioSample <fct>, condition <fct>, `|` <|>, gene_id <chr>,
#> # gene_name <chr>, entrezid <chr>, gene_biotype <chr>, gene_seq_start <chr>,
#> # gene_seq_end <chr>, seq_name <chr>, seq_strand <chr>,
#> # seq_coord_system <chr>, symbol <chr>